% detgrow Computes Time Paths for the Deterministic
% Discrete Time Neoclassical Growth Modell, Constant Technology
% Using Backward Iteration. Reference: Brunner and Strulik (2002)
% Calls the function bestmu.m and rbcfunc.m
% Compares with the Exact Solution (for theta=1)

clear all; clc
global a b theta d A Aa ka ca ks cs vs kfinal tmax

% *************************** Model Parameters *************************
theta=1;		
a=0.36;					
b=0.96;							
d=0.025;					
A=(1-b*(1-d))/(a*b);
Aa=A;
% Steady-State
ks   = (a.*b.*A/(1-b*(1-d)))^(1/(1-a));
cs   = A.*ks^a-d*ks;
ys=A*ks.^a;

% ************************* Start Value *******************************
j12=((a-1)/(a*b*theta))*(1-b*(1-d))*(1-b*(1-d)-a*b*d);
J=[1 j12; -1 1/b];
[eigvec,eigval]=eig(J);
vs=eigvec(:,1);								% stable eigenvector


% Search for best initial deviation given maxerror for approx of final value kfinal

kfinal=0.1; % Forward Looking Starting Value 
tmax=200;   % Time Horizon
mu0=5*10^-6  % Initial Guess for Initial Deviation
mu=fzero('bestmu',mu0); 
disp('best mu found')

t=zeros(1,tmax); k=zeros(tmax,1); c=zeros(tmax,1);
t(1)=0;

% *************** Compute Adjusment Dynamics *******************************
% First Step
c(1)=cs+mu*vs(1);
k(1)=ks+mu*vs(2);ka=k(1);

      
% Backward Iteration
i=1;
while i < tmax
    t(i+1)=t(i)+1;
c(i+1)=c(i)* (b*(a*A*k(i)^(a-1)+(1-d)))^(-1/theta);
ca=c(i+1);ka=k(i);
k(i+1)=fzero('rbcfunc',ka);
i=i+1;
end %backward iteration

%Reversion of Solution
t(i+2:tmax)=[];k(i+2:tmax)=[];c(i+2:tmax)=[];
c=c(length(c):-1:1); k=k(length(k):-1:1);


if d==1 & theta==1
%True Solution
ktrue=exp(a.^t.*(log(k(1))-log(a.*b.*A)./(1-a))+log(a.*b.*A)./(1-a));
ctrue=(1-b*a)*A.*ktrue.^a;
diffk=k-ktrue'; diffc=c-ctrue';
end



% plotting
set(gcf,'PaperUnits', 'centimeters','PaperType','a4letter','Units','centimeters','PaperPosition', [1 1 16 5],'Position',[1 1 16 5],'Color','w');
set(0,'DefaultTextColor','k')

subplot(2,2,1)
set(gca,'FontName','Times','FontSize',8);
plot(t,c,'b-')
hold on
if d==1 & theta==1
    plot(t,ctrue,'b+',t,c,'bo','MarkerSize',5)
end
set(gca,'Color','w','XColor','k','YColor','k','FontName','Times','FontSize',10);
%axis([0 12 1 2.5])

subplot(2,2,2)
set(gca,'FontName','Times','FontSize',8);
plot(t,k,'b-')
hold on
if d==1 & theta==1
    plot(t,ktrue,'b+',t,k,'bo','MarkerSize',5)
end
set(gca,'Color','w','XColor','k','YColor','k','FontName','Times','FontSize',10);
%axis([0 12 0 2])


subplot(2,2,3)
set(gca,'FontName','Times','FontSize',8);
plot(k,c,'b-')
hold on
if d==1 & theta==1
    plot(ktrue,ctrue,'b+',k,c,'bo','MarkerSize',5)
end
set(gca,'Color','w','XColor','k','YColor','k','FontName','Times','FontSize',10);
%axis([0 20 -0.1 +0.25])

if d==1 & theta==1
subplot(2,2,4)
plot(0,0)
plot(k,log(abs(diffc)),'b-')
hold on
set(gca,'Color','w','XColor','k','YColor','k','FontName','Times','FontSize',10);
axis([0 2 -20 -10])
end


break
gtext('{\it t}')	
gtext('{\it c}')	

gtext('{\it t}')	
gtext('{\it k}')	

gtext('{\it k}')	
gtext('{\it c}')	

gtext('{\it k}')	
gtext('{\Delta(c)}')